.mfp-bg {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 1042;
    overflow: hidden;
    position: fixed;
    background: #0b0b0b;
    opacity: 0.8;
    filter: alpha(opacity=80);
}

.mfp-wrap {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 1043;
    position: fixed;
    outline: none !important;
    -webkit-backface-visibility: hidden;
}

.mfp-container {
    text-align: center;
    position: absolute;
    width: 100%;
    height: 100%;
    left: 0;
    top: 0;
    padding: 0 8px;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
}

.mfp-container:before {
    content: '';
    display: inline-block;
    height: 100%;
    vertical-align: middle;
}

.mfp-align-top .mfp-container:before {
    display: none;
}

.mfp-content {
    position: relative;
    display: inline-block;
    vertical-align: middle;
    margin: 0 auto;
    text-align: left;
    z-index: 1045;
}

.mfp-inline-holder .mfp-content,
.mfp-ajax-holder .mfp-content {
    width: 100%;
    cursor: auto;
}

.mfp-ajax-cur {
    cursor: progress;
}

.mfp-zoom-out-cur,
.mfp-zoom-out-cur .mfp-image-holder .mfp-close {
    cursor: -webkit-zoom-out;
    cursor: zoom-out;
}

.mfp-zoom {
    cursor: pointer;
    cursor: -webkit-zoom-in;
    cursor: zoom-in;
}

.mfp-auto-cursor .mfp-content {
    cursor: auto;
}

.mfp-close,
.mfp-arrow,
.mfp-preloader,
.mfp-counter {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}

.mfp-loading.mfp-figure {
    display: none;
}

.mfp-hide {
    display: none !important;
}

.mfp-preloader {
    color: #CCC;
    position: absolute;
    top: 50%;
    width: auto;
    text-align: center;
    margin-top: -0.8em;
    left: 8px;
    right: 8px;
    z-index: 1044;
}

.mfp-preloader a {
    color: #CCC;
}

.mfp-preloader a:hover {
    color: #FFF;
}

.mfp-s-ready .mfp-preloader {
    display: none;
}

.mfp-s-error .mfp-content {
    display: none;
}

button.mfp-close,
button.mfp-arrow {
    overflow: visible;
    cursor: pointer;
    background: transparent;
    border: 0;
    -webkit-appearance: none;
    display: block;
    outline: none;
    padding: 0;
    z-index: 1046;
    -webkit-box-shadow: none;
    box-shadow: none;
}

.wb-modal button::-moz-focus-inner {
    padding: 0;
    border: 0;
}

.mfp-close {
    width: 44px;
    height: 44px;
    line-height: 44px;
    position: absolute;
    right: 0;
    top: 0;
    text-decoration: none;
    text-align: center;
    opacity: 0.65;
    filter: alpha(opacity=65);
    padding: 0 0 18px 10px;
    color: #FFF;
    font-style: normal;
    font-size: 28px;
    font-family: Arial, Baskerville, monospace;
}

.mfp-close:hover,
.mfp-close:focus {
    opacity: 1;
    filter: alpha(opacity=100);
}

.mfp-close:active {
    top: 1px;
}

.mfp-close-btn-in .mfp-close {
    color: #333;
}

.mfp-image-holder .mfp-close,
.mfp-iframe-holder .mfp-close {
    color: #FFF;
    right: -6px;
    text-align: right;
    padding-right: 6px;
    width: 100%;
}

.mfp-counter {
    position: absolute;
    top: 0;
    right: 0;
    color: #CCC;
    font-size: 12px;
    line-height: 18px;
    white-space: nowrap;
}

.mfp-arrow {
    position: absolute;
    opacity: 0.65;
    filter: alpha(opacity=65);
    margin: 0;
    top: 50%;
    margin-top: -55px;
    padding: 0;
    width: 90px;
    height: 110px;
    -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}

.mfp-arrow:active {
    margin-top: -54px;
}

.mfp-arrow:hover,
.mfp-arrow:focus {
    opacity: 1;
    filter: alpha(opacity=100);
}

.mfp-arrow:before,
.mfp-arrow:after,
.mfp-arrow .mfp-b,
.mfp-arrow .mfp-a {
    content: '';
    display: block;
    width: 0;
    height: 0;
    position: absolute;
    left: 0;
    top: 0;
    margin-top: 35px;
    margin-left: 35px;
    border: medium inset transparent;
}

.mfp-arrow:after,
.mfp-arrow .mfp-a {
    border-top-width: 13px;
    border-bottom-width: 13px;
    top: 8px;
}

.mfp-arrow:before,
.mfp-arrow .mfp-b {
    border-top-width: 21px;
    border-bottom-width: 21px;
    opacity: 0.7;
}

.mfp-arrow-left {
    left: 0;
}

.mfp-arrow-left:after,
.mfp-arrow-left .mfp-a {
    border-right: 17px solid #FFF;
    margin-left: 31px;
}

.mfp-arrow-left:before,
.mfp-arrow-left .mfp-b {
    margin-left: 25px;
    border-right: 27px solid #3F3F3F;
}

.mfp-arrow-right {
    right: 0;
}

.mfp-arrow-right:after,
.mfp-arrow-right .mfp-a {
    border-left: 17px solid #FFF;
    margin-left: 39px;
}

.mfp-arrow-right:before,
.mfp-arrow-right .mfp-b {
    border-left: 27px solid #3F3F3F;
}

.mfp-iframe-holder {
    padding-top: 40px;
    padding-bottom: 40px;
}

.mfp-iframe-holder .mfp-content {
    line-height: 0;
    width: 100%;
    max-width: 900px;
}

.mfp-iframe-holder .mfp-close {
    top: -40px;
}

.mfp-iframe-scaler {
    width: 100%;
    height: 0;
    overflow: hidden;
    padding-top: 56.25%;
}

.mfp-iframe-scaler iframe {
    position: absolute;
    display: block;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    -webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #000;
}

/* Main image in popup */
img.mfp-img {
    width: auto;
    max-width: 100%;
    height: auto;
    display: block;
    line-height: 0;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    padding: 40px 0 40px;
    margin: 0 auto;
}

/* The shadow behind the image */
.mfp-figure {
    line-height: 0;
}

.mfp-figure:after {
    content: '';
    position: absolute;
    left: 0;
    top: 40px;
    bottom: 40px;
    display: block;
    right: 0;
    width: auto;
    height: auto;
    z-index: -1;
    -webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #444;
}

.mfp-figure small {
    color: #BDBDBD;
    display: block;
    font-size: 12px;
    line-height: 14px;
}

.mfp-figure figure {
    margin: 0;
}

.mfp-bottom-bar {
    margin-top: -36px;
    position: absolute;
    top: 100%;
    left: 0;
    width: 100%;
    cursor: auto;
}

.mfp-title {
    text-align: left;
    line-height: 18px;
    color: #F3F3F3;
    word-wrap: break-word;
    padding-right: 36px;
}

.mfp-image-holder .mfp-content {
    max-width: 100%;
}

.mfp-gallery .mfp-image-holder .mfp-figure {
    cursor: pointer;
}

@media screen and (max-width: 800px) and (orientation: landscape),
screen and (max-height: 300px) {

    /**
       * Remove all paddings around the image on small screen
       */
    .mfp-img-mobile .mfp-image-holder {
        padding-left: 0;
        padding-right: 0;
    }

    .mfp-img-mobile img.mfp-img {
        padding: 0;
    }

    .mfp-img-mobile .mfp-figure:after {
        top: 0;
        bottom: 0;
    }

    .mfp-img-mobile .mfp-figure small {
        display: inline;
        margin-left: 5px;
    }

    .mfp-img-mobile .mfp-bottom-bar {
        background: rgba(0, 0, 0, 0.6);
        bottom: 0;
        margin: 0;
        top: auto;
        padding: 3px 5px;
        position: fixed;
        -webkit-box-sizing: border-box;
        box-sizing: border-box;
    }

    .mfp-img-mobile .mfp-bottom-bar:empty {
        padding: 0;
    }

    .mfp-img-mobile .mfp-counter {
        right: 5px;
        top: 3px;
    }

    .mfp-img-mobile .mfp-close {
        top: 0;
        right: 0;
        width: 35px;
        height: 35px;
        line-height: 35px;
        background: rgba(0, 0, 0, 0.6);
        position: fixed;
        text-align: center;
        padding: 0;
    }
}

@media all and (max-width: 900px) {
    .mfp-arrow {
        -webkit-transform: scale(0.75);
        transform: scale(0.75);
    }

    .mfp-arrow-left {
        -webkit-transform-origin: 0;
        transform-origin: 0;
    }

    .mfp-arrow-right {
        -webkit-transform-origin: 100%;
        transform-origin: 100%;
    }

    .mfp-container {
        padding-left: 6px;
        padding-right: 6px;
    }
}

.mfp-ie7 .mfp-img {
    padding: 0;
}

.mfp-ie7 .mfp-bottom-bar {
    width: 600px;
    left: 50%;
    margin-left: -300px;
    margin-top: 5px;
    padding-bottom: 5px;
}

.mfp-ie7 .mfp-container {
    padding: 0;
}

.mfp-ie7 .mfp-content {
    padding-top: 44px;
}

.mfp-ie7 .mfp-close {
    top: 0;
    right: 0;
    padding-top: 0;
}

.mfp-close:focus,
.mfp-arrow:focus {
    outline: 1px dotted #fff;
    outline-offset: -2px;
}

body.wb-modal>#wb-tphp,
body.wb-modal>header,
body.wb-modal>main,
body.wb-modal>footer,
body.wb-modal summary {
    visibility: hidden !important;
}

.wb-modal .lbx-hide-gal li {
    display: none;
    list-style-type: none;
}

.wb-modal .lbx-hide-gal li:first-child {
    display: block;
}

body.wb-modal .modal-dialog summary {
    visibility: visible !important;
}

.wb-modal .modal-dialog {
    left: auto;
    padding: 0;
    position: relative;
}

.wb-modal .modal-content {
    background: transparent;
}

.wb-modal .modal-body {
    background: #fff;
}

.wb-modal .modal-footer {
    background: #fff;
    margin-top: 0;
}

.mfp-gallery .modal-body {
    padding: 20px 30px;
}

.mfp-close {
    cursor: pointer !important;
    font-weight: 700;
    /* Should fix upstream in Magnific Popup rather than overriding in WET */
}

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-arrow {
    opacity: 1;
}

.mfp-arrow-left:before,
.mfp-arrow-left .mfp-b {
    border-right: 27px solid #000000;
}

.mfp-arrow-right:before,
.mfp-arrow-right .mfp-b {
    border-left: 27px solid #000000;
}

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-bottom-bar .mfp-title {
    padding-right: 5px;
    width: 75%;
}

.mfp-bottom-bar .mfp-counter {
    font-size: 1em;
    text-align: right;
    width: 25%;
}

.wb-modal dialog {
    background-color: transparent;
    border: none;
}

.wb-overlay-dlg main>*,
.wb-modal main>* {
    display: none;
}

.wb-overlay-dlg main .wb-overlay.open,
.wb-overlay-dlg main .mfp-content,
.wb-modal main .wb-overlay.open,
.wb-modal main .mfp-content {
    display: block;
}

.wb-overlay.open {
    position: static;
}

.wb-overlay.open.no-print {
    display: none;
}

.mfp-content:before,
.wb-overlay.open:before {
    content: attr(data-pgtitle);
    display: block;
    font-size: 1.9em;
}

.wb-overlay {
    background-clip: border-box;
    background-color: #fff;
    border: 0;
    border-radius: 0;
    display: none;
    -webkit-transform: translateZ(0);
    transform: translateZ(0);
    z-index: 1050;
}

.wb-overlay.wb-inview {
    display: block;
}

.wb-overlay.open {
    display: inline-block;
    position: fixed;
}

.wb-panel-l,
.wb-panel-r {
    height: 100%;
    max-width: 90%;
    top: 0;
}

.wb-bar-t,
.wb-bar-b {
    border-bottom: 0;
    left: 0;
    max-height: 90%;
    min-width: 100%;
}

.wb-popup-mid {
    max-height: 90%;
    max-width: 90%;
}

/*
     *	Overlay styles
     */
.wb-panel-l {
    left: 0;
}

.wb-panel-r {
    right: 0;
}

.wb-bar-t {
    top: 0;
}

.wb-bar-b {
    bottom: 0;
}

.wb-popup-mid {
    border-radius: 6px;
    bottom: 0;
    left: 0;
    margin: auto;
    right: 0;
    top: 0;
    width: 90%;
}

.wb-popup-full {
    height: 100%;
    left: 0;
    top: 0;
    width: 100%;
}

.mfp-bg {
    opacity: .97;
}

.wb-overlay-dlg {
    overflow: hidden;
}

.wb-overlay-dlg .overlay-bg {
    -webkit-box-shadow: 0 0 1000px 1000px black;
    box-shadow: 0 0 1000px 1000px black;
}

/*
     *	Overlay parts
     */
.wb-modal .overlay-def {
    overflow-y: auto;
}

.wb-modal .overlay-def header {
    background-color: #2e5274;
    color: #fff;
    display: block;
    padding: 0 44px 0 1em;
}

.wb-modal .overlay-def .modal-title {
    font-size: 1.55em;
    padding: 10px 0;
}

.wb-modal .overlay-def.wb-bar-t,
.wb-modal .overlay-def.wb-bar-b {
    background-color: #000;
}

.wb-modal .overlay-def.wb-bar-t header,
.wb-modal .overlay-def.wb-bar-b header {
    background-color: #000;
}

.wb-modal .overlay-def .mfp-close {
    color: #fff;
}

.wb-modal .hidden-hd .modal-body {
    padding-top: 50px;
}

.wb-modal .hidden-hd .overlay-close:not(.btn) {
    background-color: #000;
    border-radius: 999px;
    height: 1em;
    line-height: 1em;
    margin-right: 20px;
    margin-top: 10px;
    width: 1em;
}

[dir=rtl] .mfp-close {
    left: 0;
    right: auto;
}

[dir=rtl] .wb-panel-l {
    left: auto;
    right: 0;
}

[dir=rtl] .wb-panel-r {
    left: 0;
    right: auto;
}

[dir=rtl] .wb-modal .overlay-def header {
    padding: 0 1em 0 44px;
}

/*
    * Overlay-specific overrides
    */
.wb-modal .overlay-def header {
    background: #26374a;
}

.wb-modal .overlay-def .modal-header {
    background: #2e5274;
}

.wb-sl {
    background: #26374a;
    color: #fff;
    font-weight: 700;
}

.wb-sl:focus {
    color: #fff;
    text-decoration: none;
}

.wb-sl:hover {
    background-color: #444;
    color: #fff;
}


.wb-modal .modal-open {
    overflow: hidden;
}

.wb-modal .modal {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1050;
    display: none;
    overflow: hidden;
    -webkit-overflow-scrolling: touch;
    outline: 0;
}

.wb-modal .modal.fade .modal-dialog {
    -webkit-transform: translate(0, -25%);
    transform: translate(0, -25%);
    -webkit-transition: -webkit-transform 0.3s ease-out;
    transition: -webkit-transform 0.3s ease-out;
    transition: transform 0.3s ease-out;
    transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out;
}

.wb-modal .modal.in .modal-dialog {
    -webkit-transform: translate(0, 0);
    transform: translate(0, 0);
}

.wb-modal .modal-open .modal {
    overflow-x: hidden;
    overflow-y: auto;
}

.wb-modal .modal-dialog {
    position: relative;
    width: auto;
    margin: 10px;
}

.wb-modal .modal-content {
    position: relative;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #999;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 6px;
    -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    outline: 0;
}

.wb-modal .modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background-color: #000;
}

.wb-modal .modal-backdrop.fade {
    filter: alpha(opacity=0);
    opacity: 0;
}

.wb-modal .modal-backdrop.in {
    filter: alpha(opacity=50);
    opacity: 0.5;
}

.wb-modal .modal-header {
    padding: 15px;
    border-bottom: 1px solid #e5e5e5;
}

.wb-modal .modal-header:before,
.wb-modal .modal-header:after {
    display: table;
    content: " ";
}

.wb-modal .modal-header:after {
    clear: both;
}

.wb-modal .modal-header .close {
    margin-top: -2px;
}

.wb-modal .modal-title {
    margin: 0;
    line-height: 1.4375;
}

.wb-modal .modal-body {
    position: relative;
    padding: 15px;
}

.wb-modal .modal-footer {
    padding: 15px;
    text-align: right;
    border-top: 1px solid #e5e5e5;
}

.wb-modal .modal-footer:before,
.wb-modal .modal-footer:after {
    display: table;
    content: " ";
}

.wb-modal .modal-footer:after {
    clear: both;
}

.wb-modal .modal-footer .btn+.btn {
    margin-bottom: 0;
    margin-left: 5px;
}

.wb-modal .modal-footer .btn-group .btn+.btn {
    margin-left: -1px;
}

.wb-modal .modal-footer .btn-block+.btn-block {
    margin-left: 0;
}

.wb-modal .modal-scrollbar-measure {
    position: absolute;
    top: -9999px;
    width: 50px;
    height: 50px;
    overflow: scroll;
}

@media (min-width: 768px) {
    .wb-modal .modal-dialog {
        width: 600px;
        margin: 30px auto;
    }

    .wb-modal .modal-content {
        -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
        box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    }

    .wb-modal .modal-sm {
        width: 300px;
    }
}

@media (min-width: 992px) {
    .wb-modal .modal-lg {
        width: 900px;
    }
}

.wb-modal .btn-default {
    color: #335075;
    background-color: #eaebed;
    border-color: #dcdee1;
}

.wb-modal .btn-default:focus,
.wb-modal .btn-default.focus {
    color: #335075;
    background-color: #cfd1d5;
    border-color: #989da6;
}

.wb-modal .btn-default:hover {
    color: #335075;
    background-color: #cfd1d5;
    border-color: #bbbfc5;
}

.wb-modal .btn-default:active,
.wb-modal .btn-default.active,
.wb-modal .open>.btn-default.dropdown-toggle {
    color: #335075;
    background-color: #cfd1d5;
    background-image: none;
    border-color: #bbbfc5;
}

.wb-modal .btn-default:active:hover,
.wb-modal .btn-default:active:focus,
.wb-modal .btn-default:active.focus,
.wb-modal .btn-default.active:hover,
.wb-modal .btn-default.active:focus,
.wb-modal .btn-default.active.focus,
.wb-modal .open>.btn-default.dropdown-toggle:hover,
.wb-modal .open>.btn-default.dropdown-toggle:focus,
.wb-modal .open>.btn-default.dropdown-toggle.focus {
    color: #335075;
    background-color: #bbbfc5;
    border-color: #989da6;
}

.wb-modal .btn-default.disabled:hover,
.wb-modal .btn-default.disabled:focus,
.wb-modal .btn-default.disabled.focus,
.wb-modal .btn-default[disabled]:hover,
.wb-modal .btn-default[disabled]:focus,
.wb-modal .btn-default[disabled].focus,
.wb-modal fieldset[disabled] .btn-default:hover,
.wb-modal fieldset[disabled] .btn-default:focus,
.wb-modal fieldset[disabled] .btn-default.focus {
    background-color: #eaebed;
    border-color: #dcdee1;
}

.wb-modal .btn-default .badge {
    color: #eaebed;
    background-color: #335075;
}

.wb-modal .btn-primary {
    color: #fff;
    background-color: #2572b4;
    border-color: #143c5f;
}

.wb-modal .btn-primary:focus,
.wb-modal .btn-primary.focus {
    color: #fff;
    background-color: #1c578a;
    border-color: black;
}

.wb-modal .btn-primary:hover {
    color: #fff;
    background-color: #1c578a;
    border-color: #091c2d;
}

.wb-modal .btn-primary:active,
.wb-modal .btn-primary.active,
.wb-modal .open>.btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #1c578a;
    background-image: none;
    border-color: #091c2d;
}

.wb-modal .btn-primary:active:hover,
.wb-modal .btn-primary:active:focus,
.wb-modal .btn-primary:active.focus,
.wb-modal .btn-primary.active:hover,
.wb-modal .btn-primary.active:focus,
.wb-modal .btn-primary.active.focus,
.wb-modal .open>.btn-primary.dropdown-toggle:hover,
.wb-modal .open>.btn-primary.dropdown-toggle:focus,
.wb-modal .open>.btn-primary.dropdown-toggle.focus {
    color: #fff;
    background-color: #16446c;
    border-color: black;
}

.wb-modal .btn-primary.disabled:hover,
.wb-modal .btn-primary.disabled:focus,
.wb-modal .btn-primary.disabled.focus,
.wb-modal .btn-primary[disabled]:hover,
.wb-modal .btn-primary[disabled]:focus,
.wb-modal .btn-primary[disabled].focus,
.wb-modal fieldset[disabled] .btn-primary:hover,
.wb-modal fieldset[disabled] .btn-primary:focus,
.wb-modal fieldset[disabled] .btn-primary.focus {
    background-color: #2572b4;
    border-color: #143c5f;
}

.wb-modal .btn-primary .badge {
    color: #2572b4;
    background-color: #fff;
}